pybedtools.scripts.annotate
===========================

.. automodule:: pybedtools.scripts.annotate

   
   
   .. rubric:: Functions

   .. autosummary::
   
      add_closest
      add_xstream
      gen_get_name
      get_gff_name
      main
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      Attributes
      BedTool
   
   

   
   
   